"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var JSZip = require("jszip");
var utils_1 = require("./utils");
var assets_1 = require("./assets");
var templates_1 = require("./templates");
var defaultDocumentOptions = {
    orientation: 'portrait',
    margins: {},
};
function mergeOptions(options, patch) {
    return tslib_1.__assign(tslib_1.__assign({}, options), patch);
}
function generateDocument(zip) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var buffer;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, zip.generateAsync({ type: 'arraybuffer' })];
                case 1:
                    buffer = _a.sent();
                    if (global.hasOwnProperty('Blob')) {
                        return [2 /*return*/, new Blob([buffer], {
                                type: 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
                            })];
                    }
                    else if (global.hasOwnProperty('Buffer')) {
                        return [2 /*return*/, new Buffer(new Uint8Array(buffer))];
                    }
                    else {
                        throw new Error('Neither Blob nor Buffer are accessible in this environment. ' + 'Consider adding Blob.js shim');
                    }
                    return [2 /*return*/];
            }
        });
    });
}
exports.generateDocument = generateDocument;
function renderDocumentFile(documentOptions) {
    var orientation = documentOptions.orientation, margins = documentOptions.margins;
    var marginsOptions = mergeOptions(templates_1.defaultMargins, margins);
    var width = 0;
    var height = 0;
    if (orientation === 'landscape') {
        height = 12240;
        width = 15840;
    }
    else {
        width = 12240;
        height = 15840;
    }
    return templates_1.documentTemplate(width, height, orientation, marginsOptions);
}
function addFiles(htmlSource, options) {
    var zip = new JSZip();
    var documentOptions = mergeOptions(defaultDocumentOptions, options);
    zip.file('[Content_Types].xml', new Buffer(assets_1.contentTypesXml, 'utf-8'), {
        createFolders: false,
    });
    zip.folder('_rels').file('.rels', new Buffer(assets_1.relsXml, 'utf-8'), { createFolders: false });
    return zip
        .folder('word')
        .file('document.xml', renderDocumentFile(documentOptions), {
        createFolders: false,
    })
        .file('afchunk.mht', utils_1.getMHTdocument(htmlSource), {
        createFolders: false,
    })
        .folder('_rels')
        .file('document.xml.rels', new Buffer(assets_1.documentXmlRels, 'utf-8'), {
        createFolders: false,
    });
}
exports.addFiles = addFiles;
//# sourceMappingURL=internal.js.map